##  Description
The objective fact sheet defines the Key Performance Indicators (KPIs) that will measure success. Objectives link to business capabilities and initiatives so progress can be tracked over time.
Overview of all relations to/from objective:
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2748bc827a44101482d0a8463b6a0fd2_LowRes.png)
Modeling objectives is not required to get started with the first SAP LeanIX use case, application portfolio assessment.
Modeling objectives identifies business capabilities that are critical to achieving an organization’s strategy and shows how large modernization or transformation initiatives work together towards a common goal.
Objectives are typically derived from an organization’s strategy or taken from OKRs (Objectives and Key Results).
Objective examples:
  * Business objective: Reach net-zero carbon emissions by 2030
  * IT objective: Use data centers with a carbon footprint calculator for all cloud solutions by 2025
  * Business objective: Reduce IT costs by $10m in FY24
  * Business objective: Improve operational efficiency by 20% by March 2025
  * Business objective: Onboard 100 new customers in 2026
